@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010,2011,2012 The ESPResSo project
+  Copyright (C) 2010,2011,2012,2013 The ESPResSo project
   Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
     Max-Planck-Institute for Polymer Research, Theory Group
   
@@ -26,7 +26,7 @@
 #include "global.h"
 #include "particle_data.h"
 #include "interaction_data.h"
-#include "integrate.h"
+#include "reaction.h"
 #include "statistics.h"
 #include "energy.h"
 #include "pressure.h"
@@ -40,7 +40,6 @@
 #include "rotation.h"
 #include "p3m.h"
 #include "p3m-dipolar.h"
-#include "ewald.h"
 #include "mmm1d.h"
 #include "mmm2d.h"
 #include "maggs.h"
@@ -62,6 +61,8 @@
 #include "statistics_observable.h"
 #include "statistics_correlation.h"
 #include "lb-boundaries.h"
+#include "ghmc.h"
+#include "domain_decomposition.h"
 
 /** whether the thermostat has to be reinitialized before integration */
 static int reinit_thermo = 1;
@@ -98,7 +99,7 @@ void on_program_start()
   init_random();
   init_bit_random();
 
-  setup_node_grid();
+  init_node_grid();
   /* calculate initial minimimal number of cells (see tclcallback_min_num_cells) */
   min_num_cells = calc_processor_min_num_cells();
 
@@ -132,6 +133,11 @@ void on_program_start()
   lb_pre_init();
 #endif
 
+#ifdef CATALYTIC_REACTIONS
+  reaction.eq_rate=0.0;
+  reaction.sing_mult=0;
+#endif
+
   /*
     call all initializations to do only on the master node here.
   */
@@ -181,10 +187,9 @@ void on_integration_start()
 #ifdef P3M
     case COULOMB_P3M:   break;
 #endif /*P3M*/
-    case COULOMB_EWALD: break;
     default: {
       char *errtext = runtime_error(128);
-      ERROR_SPRINTF(errtext,"{014 npt only works with Ewald sum or P3M} ");
+      ERROR_SPRINTF(errtext,"{014 npt only works with P3M} ");
     }
     }
 #endif /*ELECTROSTATICS*/
@@ -263,6 +268,22 @@ if(this_node == 0){
   meta_init();
 #endif
 
+#ifdef CATALYTIC_REACTIONS
+if(reaction.ct_rate != 0.0) {
+
+   if( dd.use_vList == 0 || cell_structure.type != CELL_STRUCTURE_DOMDEC) {
+      errtext = runtime_error(128);
+      ERROR_SPRINTF(errtext,"{105 The CATALYTIC_REACTIONS feature requires verlet lists and domain decomposition} ");
+      check_runtime_errors();
+    }
+
+  if(max_cut < reaction.range) {
+    errtext = runtime_error(128);
+    ERROR_SPRINTF(errtext,"{106 Reaction range of %f exceeds maximum cutoff of %f} ", reaction.range, max_cut);
+  }
+}
+#endif
+
   /********************************************/
   /* end sanity checks                        */
   /********************************************/
@@ -303,9 +324,6 @@ void on_observable_calc()
       p3m_count_charged_particles();
       break;
 #endif
-    case COULOMB_EWALD:
-      EWALD_count_charged_particles();
-      break;
     case COULOMB_MAGGS: 
       maggs_init(); 
       break;
@@ -369,9 +387,6 @@ void on_coulomb_change()
     p3m_init();
     break;
 #endif
-  case COULOMB_EWALD:
-    EWALD_init();
-    break;
   case COULOMB_MMM1D:
     MMM1D_init();
     break;
@@ -436,6 +451,7 @@ void on_lbboundary_change()
     lb_init_boundaries();
   }
 #endif
+
 #ifdef LB_BOUNDARIES_GPU
   if(this_node == 0){
     if(lattice_switch & LATTICE_LB_GPU) {
@@ -460,9 +476,6 @@ void on_resort_particles()
   case COULOMB_MMM2D:
     MMM2D_on_resort_particles();
     break;
-  case COULOMB_EWALD:
-    EWALD_on_resort_particles();
-    break;
   default: break;
   }
 #endif /* ifdef ELECTROSTATICS */
@@ -486,9 +499,6 @@ void on_boxl_change() {
     p3m_scaleby_box_l();
     break;
 #endif
-  case COULOMB_EWALD:
-    EWALD_scaleby_box_l();
-    break;
   case COULOMB_MMM1D:
     MMM1D_init();
     break;
@@ -544,9 +554,6 @@ void on_cell_structure_change()
     p3m_init();
     break;
 #endif
-  case COULOMB_EWALD:
-    EWALD_init();
-    break;
   case COULOMB_MMM1D:
     MMM1D_init();
     break;
@@ -649,8 +656,16 @@ void on_parameter_change(int field)
     }
 #endif
   case FIELD_LANGEVIN_GAMMA:
-  case FIELD_DPD_TGAMMA:
   case FIELD_DPD_GAMMA:
+  case FIELD_DPD_TGAMMA:
+    reinit_thermo = 1;
+    break;
+  case FIELD_DPD_RCUT:
+  case FIELD_DPD_TRCUT:
+    recalc_maximal_cutoff();
+    cells_on_geometry_change(0);
+    reinit_thermo = 1;
+    break;
   case FIELD_NPTISO_G0:
   case FIELD_NPTISO_GV:
   case FIELD_NPTISO_PISTON:
