@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010,2011,2012 The ESPResSo project
+  Copyright (C) 2010,2011,2012,2013 The ESPResSo project
   Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
     Max-Planck-Institute for Polymer Research, Theory Group
   
@@ -32,6 +32,7 @@
 #include <math.h>
 #include "utils.h"
 #include "integrate.h"
+#include "reaction.h"
 #include "interaction_data.h"
 #include "particle_data.h"
 #include "communication.h"
@@ -57,6 +58,7 @@
 #include "virtual_sites.h"
 #include "adresso.h"
 #include "statistics_correlation.h"
+#include "ghmc.h"
 
 /************************************************
  * DEFINES
@@ -231,6 +233,11 @@ void integrate_vv(int n_steps)
 #endif
   }
 
+#ifdef GHMC
+    if(thermo_switch & THERMO_GHMC)
+      ghmc_init();
+#endif
+
   if (check_runtime_errors())
     return;
 
@@ -244,6 +251,13 @@ void integrate_vv(int n_steps)
     save_old_pos();
 #endif
 
+#ifdef GHMC
+    if(thermo_switch & THERMO_GHMC) {
+      if ((int) fmod(i,ghmc_nmd) == 0)
+        ghmc_momentum_update();
+    }
+#endif
+
     /* Integration Steps: Step 1 and 2 of Velocity Verlet scheme:
        v(t+0.5*dt) = v(t) + 0.5*dt * f(t)
        p(t + dt)   = p(t) + dt * v(t+0.5*dt)
@@ -321,6 +335,10 @@ void integrate_vv(int n_steps)
     if (check_runtime_errors()) break;
 #endif
 
+#ifdef CATALYTIC_REACTIONS
+  integrate_reaction();
+#endif
+
     /* Communication step: ghost forces */
     ghost_communicator(&cell_structure.collect_ghost_force_comm);
 
@@ -379,6 +397,13 @@ void integrate_vv(int n_steps)
       nptiso.p_inst_av += nptiso.p_inst;
 #endif
 
+#ifdef GHMC
+    if(thermo_switch & THERMO_GHMC) {
+      if ((int) fmod(i,ghmc_nmd) == ghmc_nmd-1)
+        ghmc_mc();
+    }
+#endif
+
     /* Propagate time: t = t+dt */
     sim_time += time_step;
   }
@@ -398,6 +423,11 @@ void integrate_vv(int n_steps)
   }
 #endif
 
+#ifdef GHMC
+  if(thermo_switch & THERMO_GHMC)
+    ghmc_close();
+#endif
+
 }
 
 /************************************************************/
