@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010,2011,2012 The ESPResSo project
+  Copyright (C) 2010,2011,2012,2013 The ESPResSo project
   Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
     Max-Planck-Institute for Polymer Research, Theory Group
   
@@ -41,7 +41,7 @@
 #define LJCOS2
 #define BUCKINGHAM
 #define SOFT_SPHERE
-#define BOND_ANGLE_COSINE
+#define BOND_ANGLE
 
 #define MPI_CORE
 #define FORCE_CORE
