@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010,2011,2012 The ESPResSo project
+  Copyright (C) 2010,2011,2012,2013 The ESPResSo project
   Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
     Max-Planck-Institute for Polymer Research, Theory Group
   
@@ -1274,6 +1274,7 @@ static double p3m_mc_time(char **log, int mesh[3], int cao,
      has infinite error estimate, as required. Therefore if the high boundary fails, there is no possible r_cut */
   if ((*_accuracy = p3m_get_accuracy(mesh, cao, r_cut_iL_max, _alpha_L, &rs_err, &ks_err)) > p3m.params.accuracy) {
     /* print result */
+    P3M_TRACE(puts("p3m_mc_time: accuracy not achieved."));
     sprintf(b, "%-4d %-3d %.5e %.5e %.5e %.3e %.3e accuracy not achieved\n",
 	    mesh[0], cao, r_cut_iL_max, *_alpha_L, *_accuracy, rs_err, ks_err);
     *log = strcat_alloc(*log, b);
@@ -1302,8 +1303,6 @@ static double p3m_mc_time(char **log, int mesh[3], int cao,
   if (coulomb.method == COULOMB_ELC_P3M && elc_params.gap_size <= 1.1*r_cut_iL*box_l[0]) {
     P3M_TRACE(fprintf(stderr, "p3m_mc_time: mesh (%d, %d, %d) cao %d r_cut %f reject r_cut %f > gap %f\n", mesh[0],mesh[1],mesh[2], cao, r_cut_iL,
                      2*r_cut_iL*box_l[0], elc_params.gap_size));
-    P3M_TRACE(fprintf(stderr, "p3m_mc_time: mesh %d cao %d r_cut %f reject r_cut %f > gap %f\n", mesh, cao, r_cut_iL,
-		      2*r_cut_iL*box_l[0], elc_params.gap_size));
     /* print result */
     sprintf(b, "%-4d %-3d %.5e %.5e %.5e %.3e %.3e conflict with ELC\n",
 	    mesh[0], cao, r_cut_iL, *_alpha_L, *_accuracy, rs_err, ks_err);
@@ -1321,7 +1320,6 @@ static double p3m_mc_time(char **log, int mesh[3], int cao,
     sprintf(b, "%-4d %-3d %.5e %.5e %.5e %.3e %.3e radius dangerously high\n\n",
 	    mesh[0], cao, r_cut_iL, *_alpha_L, *_accuracy, rs_err, ks_err);
     *log = strcat_alloc(*log, b);
-    return -P3M_TUNE_CUTOFF_TOO_LARGE;
   }
   int_time = p3m_mcr_time(mesh, cao, r_cut_iL, *_alpha_L);
   if (int_time == -1) {
@@ -1332,7 +1330,6 @@ static double p3m_mc_time(char **log, int mesh[3], int cao,
   *_accuracy = p3m_get_accuracy(mesh, cao, r_cut_iL, _alpha_L, &rs_err, &ks_err);
 
   P3M_TRACE(fprintf(stderr, "p3m_mc_time: mesh (%d, %d, %d) cao %d r_cut %f time %f\n", mesh[0], mesh[1], mesh[2], cao, r_cut_iL, int_time));
-  P3M_TRACE(fprintf(stderr, "p3m_mc_time: mesh %d cao %d r_cut %f time %f\n", mesh, cao, r_cut_iL, int_time));
   /* print result */
   sprintf(b, "%-4d %-3d %.5e %.5e %.5e %.3e %.3e %-8d\n",
 	  mesh[0], cao, r_cut_iL, *_alpha_L, *_accuracy, rs_err, ks_err, (int)int_time);
@@ -1464,7 +1461,7 @@ static double p3m_m_time(char **log, int mesh[3],
 }
 
 int p3m_adaptive_tune(char **log) {
-  int  mesh[3] = {0, 0, 0}, tmp_mesh_points; 
+  int  mesh[3] = {0, 0, 0}; 
   int tmp_mesh[3];
   double r_cut_iL_min, r_cut_iL_max, r_cut_iL = -1, tmp_r_cut_iL=0.0;
   int    cao_min, cao_max,           cao      = -1, tmp_cao;
@@ -1479,6 +1476,14 @@ int p3m_adaptive_tune(char **log) {
     return ES_ERROR;
   }
 
+  if (p3m.params.epsilon != P3M_EPSILON_METALLIC) {
+    if( !((box_l[0] == box_l[1]) &&
+	  (box_l[1] == box_l[2]))) {
+      *log = strcat_alloc(*log, "{049 P3M_init: Nonmetallic epsilon requires cubic box} ");
+      return ES_ERROR;
+    }
+  }
+
   /* preparation */
   mpi_bcast_event(P3M_COUNT_CHARGES);
   /* Print Status */
@@ -1496,8 +1501,7 @@ int p3m_adaptive_tune(char **log) {
   /* parameter ranges */
   /* if at least the number of meshpoints in one direction is not set, we have to tune it. */
   if (p3m.params.mesh[0] == 0 || p3m.params.mesh[1] == 0 || p3m.params.mesh[2] == 0) {
-    tmp_mesh_points = p3m.sum_qpart;
-    mesh_density_min = pow(p3m.sum_qpart / (box_l[0] * box_l[1] * box_l[2]) , 1.0/3.0) - 0.1;
+    mesh_density_min = pow(p3m.sum_qpart / (box_l[0] * box_l[1] * box_l[2]) , 1.0/3.0);
     mesh_density_max = 256 / pow(box_l[0] * box_l[1] * box_l[2], 1.0/3.0);
     /* this limits the tried meshes if the accuracy cannot
        be obtained with smaller meshes, but normally not all these
@@ -1515,7 +1519,7 @@ int p3m_adaptive_tune(char **log) {
   
   if(p3m.params.r_cut_iL == 0.0) {
     r_cut_iL_min = 0;
-    r_cut_iL_max = dmin(min_local_box_l, min_box_l/2) - skin;
+    r_cut_iL_max = dmin(min_local_box_l, min_box_l/2.0) - skin;
     r_cut_iL_min *= box_l_i[0];
     r_cut_iL_max *= box_l_i[0];
   }
@@ -1862,6 +1866,16 @@ int p3m_sanity_checks()
     ERROR_SPRINTF(errtxt,"{048a P3M_init: node grid must be sorted, largest first} ");
     ret = 1;
   }
+  
+  if (p3m.params.epsilon != P3M_EPSILON_METALLIC) {
+    if( !((p3m.params.mesh[0] == p3m.params.mesh[1]) &&
+	  (p3m.params.mesh[1] == p3m.params.mesh[2]))) {
+	  errtxt = runtime_error(128);
+	  ERROR_SPRINTF(errtxt,"{049 P3M_init: Nonmetallic epsilon requires cubic box} ");
+	  ret = 1;
+	}
+  }
+  
 
   return ret;
 }
