@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010,2012 The ESPResSo project
+  Copyright (C) 2010,2012,2013 The ESPResSo project
   Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
     Max-Planck-Institute for Polymer Research, Theory Group
   
@@ -178,7 +178,11 @@ MDINLINE void calc_bonded_force(Particle *p1, Particle *p2, Bonded_ia_parameters
       break;
 #endif
       /* since it is not clear at the moment how to handle a many body interaction here, I skip it */
-    case BONDED_IA_ANGLE:
+    case BONDED_IA_ANGLE_HARMONIC:
+      (*i)++; force[0] = force[1] = force[2] = 0; break;
+    case BONDED_IA_ANGLE_COSINE:
+      (*i)++; force[0] = force[1] = force[2] = 0; break;
+    case BONDED_IA_ANGLE_COSSQUARE:
       (*i)++; force[0] = force[1] = force[2] = 0; break;
     case BONDED_IA_ANGLEDIST:
       (*i)++; force[0] = force[1] = force[2] = 0; break;
@@ -255,12 +259,26 @@ MDINLINE void calc_three_body_bonded_forces(Particle *p1, Particle *p2, Particle
 #endif
 
   switch(iaparams->type) {
-#ifdef BOND_ANGLE
-  case BONDED_IA_ANGLE:
+#ifdef BOND_ANGLE_OLD
+  case BONDED_IA_ANGLE_OLD:
     // p1 is *p_mid, p2 is *p_left, p3 is *p_right
     calc_angle_3body_forces(p1, p2, p3, iaparams, force1, force2, force3);
     break;
 #endif
+#ifdef BOND_ANGLE
+  case BONDED_IA_ANGLE_HARMONIC:
+    // p1 is *p_mid, p2 is *p_left, p3 is *p_right
+    calc_angle_harmonic_3body_forces(p1, p2, p3, iaparams, force1, force2, force3);
+    break;
+ case BONDED_IA_ANGLE_COSINE:
+    // p1 is *p_mid, p2 is *p_left, p3 is *p_right
+    calc_angle_cosine_3body_forces(p1, p2, p3, iaparams, force1, force2, force3);
+    break;
+  case BONDED_IA_ANGLE_COSSQUARE:
+    // p1 is *p_mid, p2 is *p_left, p3 is *p_right
+    calc_angle_cossquare_3body_forces(p1, p2, p3, iaparams, force1, force2, force3);
+    break;
+#endif
 #ifdef TABULATED
   case BONDED_IA_TABULATED:
     switch(iaparams->p.tab.type) {
@@ -357,7 +375,7 @@ MDINLINE void add_three_body_bonded_stress(Particle *p1) {
     iaparams = &bonded_ia_params[type_num];
     type = iaparams->type;
 
-    if(type == BONDED_IA_ANGLE) {
+    if(type == BONDED_IA_ANGLE_HARMONIC || type == BONDED_IA_ANGLE_COSINE || type == BONDED_IA_ANGLE_COSSQUARE){
       p2 = local_particles[p1->bl.e[++i]];
       p3 = local_particles[p1->bl.e[++i]];
 
@@ -390,6 +408,21 @@ MDINLINE void add_three_body_bonded_stress(Particle *p1) {
     else if(type == BONDED_IA_FENE) {
       i = i + 2;
     }
+    else if(type == BONDED_IA_STRETCHING_FORCE) {
+      i = i + 2;
+    }
+    else if(type == BONDED_IA_AREA_FORCE_LOCAL) {
+      i = i + 3;
+    }
+    else if(type == BONDED_IA_AREA_FORCE_GLOBAL) {
+      i = i + 3;
+    }
+    else if(type == BONDED_IA_BENDING_FORCE) {
+      i = i + 4;
+    }
+    else if(type == BONDED_IA_VOLUME_FORCE) {
+      i = i + 3;
+    }
     else if(type == BONDED_IA_HARMONIC) {
       i = i + 2;
     }
@@ -480,6 +513,7 @@ MDINLINE void add_kinetic_virials(Particle *p1,int v_comp)
   else
     virials.data.e[0] += (SQR(p1->m.v[0]) + SQR(p1->m.v[1]) + SQR(p1->m.v[2]))*PMASS(*p1);
 
+
   /* ideal gas contribution (the rescaling of the velocities by '/=time_step' each will be done later) */
   for(k=0;k<3;k++)
     for(l=0;l<3;l++)
