@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010,2011,2012 The ESPResSo project
+  Copyright (C) 2010,2011,2012,2013 The ESPResSo project
   Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
     Max-Planck-Institute for Polymer Research, Theory Group
   
@@ -259,13 +259,18 @@ int tclcommand_lbboundary_wall(LB_Boundary *lbb, Tcl_Interp *interp, int argc, c
       	 Tcl_GetDouble(interp, argv[2], &(lbb->velocity[1])) == TCL_ERROR ||
 	       Tcl_GetDouble(interp, argv[3], &(lbb->velocity[2])) == TCL_ERROR)
 	      return (TCL_ERROR);
-      else {
+
+      if (lattice_switch & LATTICE_LB_GPU) {	
+#ifdef LB_GPU
+        /* No velocity rescaling is required */
+#endif
+      } else {	
 #ifdef LB
         lbb->velocity[0]*=lbpar.tau/lbpar.agrid;
         lbb->velocity[1]*=lbpar.tau/lbpar.agrid;
         lbb->velocity[2]*=lbpar.tau/lbpar.agrid;
 #endif
-      }
+			}
       
       argc -= 4; argv += 4;
     }
@@ -788,12 +793,7 @@ int tclcommand_lbboundary(ClientData data, Tcl_Interp *interp, int argc, char **
       return (TCL_ERROR);
     }
 
-    if (lattice_switch & LATTICE_LB_GPU) {
-      Tcl_AppendResult(interp, "Error in lbboundary force: cannot read out forces from the GPU code" ,(char *) NULL);
-      return (TCL_ERROR);	
-    }
-
-#ifdef LB
+#if defined (LB) || defined (LB_GPU)
     char buffer[3*TCL_DOUBLE_SPACE+3];
     double force[3];
 
