@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2010,2011,2012 The ESPResSo project
+  Copyright (C) 2010,2011,2012,2013 The ESPResSo project
   
   This file is part of ESPResSo.
   
@@ -263,6 +263,18 @@ int tclcommand_observable_particle_velocities(Tcl_Interp* interp, int argc, char
   return TCL_OK;
 }
 
+int tclcommand_observable_particle_angular_momentum(Tcl_Interp* interp, int argc, char** argv, int* change, observable* obs) {
+  IntList* ids;
+  int temp;
+  if (parse_id_list(interp, argc-1, argv+1, &temp, &ids) != TCL_OK ) 
+    return TCL_ERROR;
+  obs->fun=&observable_particle_angular_momentum;
+  obs->args=ids;
+  obs->n=3*ids->n;
+  *change=1+temp;
+  return TCL_OK;
+}
+
 int tclcommand_observable_com_velocity(Tcl_Interp* interp, int argc, char** argv, int* change, observable* obs) {
   IntList* ids;
   int temp, blocksize;
@@ -814,6 +826,7 @@ int tclcommand_observable(ClientData data, Tcl_Interp *interp, int argc, char **
       observables=(observable**) realloc(observables, (n_observables+1)*sizeof(observable*)); 
 
     REGISTER_OBSERVABLE(particle_velocities, tclcommand_observable_particle_velocities,id);
+    REGISTER_OBSERVABLE(particle_angular_momentum, tclcommand_observable_particle_angular_momentum,id);
     REGISTER_OBSERVABLE(particle_forces, tclcommand_observable_particle_forces,id);
     REGISTER_OBSERVABLE(com_velocity, tclcommand_observable_com_velocity,id);
     REGISTER_OBSERVABLE(com_position, tclcommand_observable_com_position,id);
@@ -1297,7 +1310,7 @@ int tclcommand_observable_print_formatted(Tcl_Interp* interp, int argc, char** a
 
 
 int sf_print_usage(Tcl_Interp* interp) {
-  Tcl_AppendResult(interp, "\nusage: structure_factor order delta_t tau_max  tau_lin", (char *)NULL);
+  Tcl_AppendResult(interp, "\nusage: structure_factor order delta_t tau_max tau_lin", (char *)NULL);
   return TCL_ERROR;
 }
 
