@@ -12,6 +12,7 @@
 #define COMFIXED
 #define MOLFORCES
 #define BOND_VIRTUAL
+#define GRANDCANONICAL
 
 #define NEMD
 #define NPT 
@@ -35,7 +36,7 @@
 #define SOFT_SPHERE
 #define INTER_RF
 
-#define BOND_ANGLE_COSINE
+#define BOND_ANGLE
 #define BOND_ANGLEDIST
 
 #define VIRTUAL_SITES_RELATIVE
